%define compat_versions             2.0 3.0 3.1 3.2 4.0
%define modular_versions            3.1 3.2

# populate the Provides for the compat versions and the old 3.x modular setup
# this way we only have to change the lists above when we bump up
# (at least until LSB drops something, or we choose to)
%define compat_provides_noarch      %(for ver in %{compat_versions};do echo -n "lsb-noarch = $ver ";done)
%define core_compat_provides_noarch %(for ver in %{compat_versions};do echo -n "lsb-core-noarch = $ver ";done)
%define compat_provides_arch        %(for ver in %{compat_versions};do echo -n "lsb-%{lsb_arch} = $ver ";done)
%define core_compat_provides_arch   %(for ver in %{compat_versions};do echo -n "lsb-core-%{lsb_arch} = $ver ";done)
%define modular_provides_noarch     %(for ver in %{modular_versions};do echo -n "lsbcxx-noarch = $ver lsb-graphics-noarch = $ver ";done)
%define modular_provides_arch       %(for ver in %{modular_versions};do echo -n "lsbcxx-%{lsb_arch} = $ver lsb-graphics-%{lsb_arch} = $ver ";done)

%define lsb_arch ia32
%ifarch x86_64
%define lsb_arch amd64
%endif

Name:           lsb
Version:        4.1
Release:        %mkrel 24
Summary:        The skeleton package defining packages needed for LSB compliance
License:        GPL
Group:          System/Base
URL:            http://www.linuxfoundation.org/collaborate/workgroups/lsb
Source0:        tmpdirlsb.sh
Source1:        install_initd
Source2:        remove_initd

ExclusiveArch:  %{ix86} x86_64

%description
The skeleton package defining packages needed for LSB compliance.
Note: To successfuly run the runtime test suites, install lsb-test.

#--------------------------------------------------------------------------------

%package        %{_lib}
Summary:        The skeleton package defining packages needed for LSB compliance
Group:          System/Base

Requires:       lsb-noarch
Requires:       lsb-core-%{_lib}

# former lsb-cxx - both arches called libfoo
Requires:       libstdc++6

# former lsb-graphics
Requires:       %mklibname x11_ 6
Requires:       %mklibname xext 6
Requires:       %mklibname xi 6
Requires:       %mklibname xt 6
Requires:       %mklibname xtst 6
Requires:       %mklibname xft 2
Requires:       %mklibname freetype 6
Requires:       %mklibname xrender 1
Requires:       %mklibname mesagl 1
Requires:       %mklibname mesaglu 1

# former lsb-desktop
Requires:       %mklibname xml 2_2
Requires:       %mklibname gtk+2.0_ 0
Requires:       %mklibname png 12 0
Requires:       %mklibname cairo 2
Requires:       %mklibname pango 1.0_0
Requires:       %mklibname fontconfig 1
Requires:       %mklibname qt 3
Requires:       %mklibname jpeg 62

# former lsb-qt4
Requires:       qt4-common >= 4.2.3
# %%mklibname doesn't work here
Requires:       %{_lib}qtopengl4 >= 4.2.3
Requires:       %{_lib}qtsvg4 >= 4.2.3
Requires:       %{_lib}qtnetwork4 >= 4.2.3
Requires:       %{_lib}qtsql4 >= 4.2.3
Requires:       %{_lib}qtxml4 >= 4.2.3

# printing
Requires:       %mklibname cups 2

# multimedia
Requires:       %mklibname alsa 2

# security
Requires:       %mklibname nss 3
Requires:       %mklibname nspr 4

Provides:       lsb-%{lsb_arch} = %{version}
Provides:       %{compat_provides_arch}
Provides:       %{modular_provides_arch}

Conflicts:      lsb-release < 2.0

Provides:       lsb-cxx
Obsoletes:      lsb-cxx
Provides:       lsb-graphics
Obsoletes:      lsb-graphics
Provides:       lsb-desktop
Obsoletes:      lsb-desktop
Provides:       lsb-desktop-qt4
Obsoletes:      lsb-desktop-qt4
Provides:       lsb = %{version}
Obsoletes:      lsb <= %{version}

%description %{_lib}
The skeleton package defining packages needed for LSB compliance.
Note: To successfuly run the runtime test suites, install lsb-test.

#--------------------------------------------------------------------------------

%package        noarch
Summary:        Architecture neutral components of LSB
Group:          System/Base

# former lsb-desktop
Requires:       xdg-utils

# interpreted languages
Requires:       python
Requires:       perl perl-CGI
Requires:       perl-Class-ISA perl-Pod-Plainer
# bundled with perl also
Requires:       perl(Safe)
Requires:       perl(Getopt::Long)
Requires:       perl(Pod::Perldoc)

# printing
Requires:       ghostscript cups-filters cups-common

Provides:       %{compat_provides_noarch}
Provides:       %{modular_provides_noarch}

%description noarch
The architecture-neutral requirements for LSB compliance.

#--------------------------------------------------------------------------------

%package        core-%{_lib}
Summary:        Core requirements needed for LSB compliance
Group:          System/Base

Requires:       lsb-core-noarch
Requires:       %{_lib}glibc_lsb
Requires:       %mklibname pam 0
Requires:       %mklibname ncurses 5

Provides:       lsb-core-%{lsb_arch} = %{version}
Provides:       %{core_compat_provides_arch}
Provides:       lsb-core = %{version}
Obsoletes:      lsb-core

%description core-%{_lib}
The core requirements for LSB compliance.

#--------------------------------------------------------------------------------

%package        core-noarch
Summary:        Architecture neutral components of lsb-core
Group:          System/Base

Requires(pre):  filesystem >= 2.1.9-18
Requires:       pax lsb-release make sendmail-command ed
Requires:       binutils bc nail at m4 patch
Requires:       diffutils file gettext chkconfig

Provides:       %{core_compat_provides_noarch}

%description core-noarch
The architecture-neutral core requirements for LSB compliance.

#--------------------------------------------------------------------------------

%package        test
Summary:        Requirements needed to successfully run the LSB runtime tests
Group:          System/Base

Requires:       lsb
Requires:       perl-DBI perl-devel perl-XML-Parser perl-URI
Requires:       perl-Locale-Maketext perl-Shell glibc-i18ndata
Requires:       locales-de locales-en locales-es locales-fr locales-is
Requires:       locales-it locales-ja locales-se locales-ta locales-zh
Requires:       wget qt4-database-plugin-sqlite qt3-Sqlite libx11-common
Requires(pre):          rpm-helper
Requires(postun):       rpm-helper

%description test
This packages pulls in additional packages not specified by LSB, but
required to successfully run the LSB runtime tests.

#--------------------------------------------------------------------------------
%prep
#%%setup -q

%install
cat << EOF > README.urpmi
To run the LSB binary test suite, download the latest version from
ftp://ftp.linuxfoundation.org/pub/lsb/test_suites/released/binary/runtime/
and install lsb-dist-checker or lsb-task-dist-testkit.

There is a GUI test manager now, lsb-dist-checker that can guide you
through the test/certification process.

There are also yum repos at:
 http://ftp.linuxfoundation.org/pub/lsb/repositories/yum/
EOF

mkdir -p %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}%{_datadir}/nls
mkdir -p %{buildroot}%{_datadir}/tmac
mkdir -p %{buildroot}%{_var}/cache/fonts
mkdir -p %{buildroot}%{_var}/games
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_sysconfdir}/lsb-release.d
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_prefix}/lib/%{name}
mkdir -p %{buildroot}/srv
mkdir -p %{buildroot}%{_sysconfdir}/opt
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install -m 755 %{SOURCE0} %{buildroot}%{_sysconfdir}/profile.d
install -m 755 %{SOURCE1} %{buildroot}%{_prefix}/lib/%{name}
install -m 755 %{SOURCE2} %{buildroot}%{_prefix}/lib/%{name}

touch %{buildroot}%{_sysconfdir}/lsb-release.d/lsb-%{version}-%{lsb_arch}
touch %{buildroot}%{_sysconfdir}/lsb-release.d/lsb-%{version}-noarch
touch %{buildroot}%{_sysconfdir}/lsb-release.d/core-%{version}-%{lsb_arch}
touch %{buildroot}%{_sysconfdir}/lsb-release.d/core-%{version}-noarch
rm -f lsb-noarch-files.txt lsb-files.txt

for lsbver in %{compat_versions}; do
  touch %{buildroot}%{_sysconfdir}/lsb-release.d/lsb-$lsbver-noarch
  echo %{_sysconfdir}/lsb-release.d/lsb-$lsbver-noarch >> lsb-noarch-files.txt
  touch %{buildroot}%{_sysconfdir}/lsb-release.d/lsb-$lsbver-%{lsb_arch}
  echo %{_sysconfdir}/lsb-release.d/lsb-$lsbver-%{lsb_arch} >> lsb-files.txt
  touch %{buildroot}%{_sysconfdir}/lsb-release.d/core-$lsbver-noarch
  touch %{buildroot}%{_sysconfdir}/lsb-release.d/core-$lsbver-%{lsb_arch}
done

for lsbver in %{modular_versions}; do
  touch %{buildroot}%{_sysconfdir}/lsb-release.d/cxx-$lsbver-noarch
  echo %{_sysconfdir}/lsb-release.d/cxx-$lsbver-noarch >> lsb-noarch-files.txt
  touch %{buildroot}%{_sysconfdir}/lsb-release.d/cxx-$lsbver-%{lsb_arch}
  echo %{_sysconfdir}/lsb-release.d/cxx-$lsbver-%{lsb_arch} >> lsb-files.txt
  touch %{buildroot}%{_sysconfdir}/lsb-release.d/graphics-$lsbver-noarch
  echo %{_sysconfdir}/lsb-release.d/graphics-$lsbver-noarch >> lsb-noarch-files.txt
  touch %{buildroot}%{_sysconfdir}/lsb-release.d/graphics-$lsbver-%{lsb_arch}
  echo %{_sysconfdir}/lsb-release.d/graphics-$lsbver-%{lsb_arch} >> lsb-files.txt
done

cat << EOF > %{buildroot}%{_sysconfdir}/profile.d/root-ulimit.sh
#!/bin/sh
# enable a nonzero core file value for root (exec_A test issues)
[ "\$UID" = "0" ] && ulimit -c 1000 > /dev/null 2>&1
EOF

cat << EOF > %{buildroot}%{_bindir}/lsbinstall
#!/bin/sh
exit 0
EOF

cat << EOF > %{buildroot}%{_sbindir}/fasthalt
#!/bin/sh
#start fasthalt
/sbin/halt -f
#end fasthalt
EOF

cat << EOF > %{buildroot}%{_sbindir}/fastboot
#!/bin/sh
#start fastboot
/sbin/reboot -f
#end fastboot
EOF

cat << EOF > %{buildroot}%{_sysconfdir}/hosts.equiv
# Sample hosts.equiv file for LSB compliance
# see man hosts.equiv for usage.
EOF

cat << EOF > %{buildroot}%{_sysconfdir}/hosts.lpd
#
# hosts.lpd     This file describes the names of the hosts which are
#               allowed to use the remote printer services of this
#               host.  This file is used by the LPD subsystem.
#		Added for LSB compiance.
EOF

cat << EOF > %{buildroot}%{_sysconfdir}/gateways
# sample gateways file for LSB compliance. Database of gateways
# used by routed. Sample format shown below.
# [ net | host ] name1 gateway name2 metric value [ passive | active | external ]
EOF

chmod 0755 %{buildroot}%{_sysconfdir}/profile.d/root-ulimit.sh
chmod 0755 %{buildroot}%{_bindir}/lsbinstall
chmod 0755 %{buildroot}%{_sbindir}/fastboot
chmod 0755 %{buildroot}%{_sbindir}/fasthalt
chmod 0644 %{buildroot}%{_sysconfdir}/hosts.equiv
chmod 0644 %{buildroot}%{_sysconfdir}/hosts.lpd
chmod 0644 %{buildroot}%{_sysconfdir}/gateways

# (sb) concession for lsb-apache to run
%pre test
%_pre_groupadd nobody

%postun test
%_postun_groupdel nobody

%files %{_lib} -f lsb-files.txt
%config(noreplace) %{_sysconfdir}/lsb-release.d/lsb-%{version}-%{lsb_arch}

%files noarch -f lsb-noarch-files.txt
%config(noreplace) %{_sysconfdir}/lsb-release.d/lsb-%{version}-noarch

%files core-%{_lib}
%config(noreplace) %{_sysconfdir}/lsb-release.d/core-*-%{lsb_arch}

%files core-noarch
%{_datadir}/nls
%{_datadir}/tmac
%{_var}/cache/fonts
%{_var}/games
%{_sbindir}/fasthalt
%{_sbindir}/fastboot
%{_bindir}/lsbinstall
%dir %{_prefix}/lib/%{name}
%{_prefix}/lib/%{name}/install_initd
%{_prefix}/lib/%{name}/remove_initd
%config(noreplace) %{_sysconfdir}/hosts.equiv
%config(noreplace) %{_sysconfdir}/hosts.lpd
%config(noreplace) %{_sysconfdir}/gateways
%config(noreplace) %{_sysconfdir}/lsb-release.d/core-*-noarch

%files test
%config(noreplace) %{_sysconfdir}/profile.d/tmpdirlsb.sh
%config(noreplace) %{_sysconfdir}/profile.d/root-ulimit.sh


%changelog
* Sat Feb 15 2020 umeabot <umeabot> 4.1-24.mga8
+ Revision: 1526668
- Mageia 8 Mass Rebuild
+ tmb <tmb>
- rebuild for Cauldron

* Sun Sep 23 2018 umeabot <umeabot> 4.1-22.mga7
+ Revision: 1299353
- Mageia 7 Mass Rebuild

* Thu Oct 12 2017 tv <tv> 4.1-21.mga7
+ Revision: 1171295
- requires cups-filters instead of foomatic-filters

* Wed Mar 09 2016 wally <wally> 4.1-20.mga6
+ Revision: 988502
- replace perl-Foo-Bar requires with perl(Foo::Bar) requires for modules bundled also with perl

* Mon Feb 08 2016 umeabot <umeabot> 4.1-19.mga6
+ Revision: 944061
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 4.1-18.mga5
+ Revision: 741468
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.1-17.mga5
+ Revision: 682008
- Mageia 5 Mass Rebuild
+ daviddavid <daviddavid>
- update URL

* Fri Oct 18 2013 umeabot <umeabot> 4.1-16.mga4
+ Revision: 507563
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 4.1-15.mga3
+ Revision: 359020
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Aug 13 2012 stewb <stewb> 4.1-14.mga3
+ Revision: 281093
- New requires for perl module changes (bug 7020)

* Sat Jul 21 2012 colin <colin> 4.1-13.mga3
+ Revision: 273158
- Update for usrmove

* Tue Jun 12 2012 stewb <stewb> 4.1-12.mga3
+ Revision: 259999
- LSB requires Getopt::Long, not being pulled in now with perl uplift

* Sun Mar 18 2012 fwang <fwang> 4.1-11.mga2
+ Revision: 223799
- do not promote png12 flavour of gdk_pixbuf, as it is not listed in lsb standard

* Fri Sep 23 2011 fwang <fwang> 4.1-10.mga2
+ Revision: 146922
- requires libpng12 flavour of gdk-pixbuf loaders

* Thu Sep 08 2011 stewb <stewb> 4.1-9.mga2
+ Revision: 141443
- 'fix standard-dir-owned-by-package' lint issues (drop the dirs, nothing else seems to own them but /shrug)
+ pterjan <pterjan>
- Fix libpng dependency

* Fri Jun 17 2011 stewb <stewb> 4.1-8.mga2
+ Revision: 108771
- Require perl-Class-ISA perl-Pod-Plainer, deprecated upstream and in LSB
  but will still be required for a few LSB releases before dropped

* Sun Apr 03 2011 pterjan <pterjan> 4.1-7.mga1
+ Revision: 80020
- Remove some useless provides and some self-obsoletes

* Sun Apr 03 2011 stewb <stewb> 4.1-6.mga1
+ Revision: 80003
- bump release and see if we get the whole set this time

* Wed Mar 30 2011 stewb <stewb> 4.1-5.mga1
+ Revision: 79048
- Rename subpackages, rework deps for bi-arch support
  Drop some deps we can do without
  Move the nobody account setup to lsb-test
  We were missing core-4.1-* in lsb_release - add

* Thu Mar 17 2011 stewb <stewb> 4.1-4.mga1
+ Revision: 73256
- perl-Pod-Perldoc is required for perl, clean up/remove a bunch os lsb-test requires we can do without these days

* Thu Feb 17 2011 stewb <stewb> 4.1-3.mga1
+ Revision: 52922
- fix libjpeg requires, add libqtxml, add perl-URI (for tests), commands -> noarch subpackages

* Mon Jan 31 2011 stewb <stewb> 4.1-2.mga1
+ Revision: 45375
- s/slocate/mlocate/, drop hplip-hpijs (test provides)

* Thu Jan 27 2011 stewb <stewb> 4.1-1.mga1
+ Revision: 42349
- imported package lsb


* Thu Jan 27 2011 Stew Benedict <stewbintn@gmail.com>
- initial import, bump to 4.1
- fix mdv bug 61699 (missing deps)
- bi-arch changes (core -> core + core-noarch, lsb -> lsb + lsb-noarch)
  (still needs work to get full bi-arch support on x86_64, related to 
   mdv bug 62031)

* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 4.0-4mdv2011.0
+ Revision: 606422
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 4.0-3mdv2010.1
+ Revision: 523212
- rebuilt for 2010.1

* Tue Oct 06 2009 Frederik Himpe <fhimpe@mandriva.org> 4.0-2mdv2010.0
+ Revision: 455268
- Replace file requires by package requires (#53526)

* Sun Sep 20 2009 Anne Nicolas <ennael@mandriva.org> 4.0-1mdv2010.0
+ Revision: 445867
- Update lsb package qith Stew patch (#40175)

* Wed Sep 09 2009 Frederik Himpe <fhimpe@mandriva.org> 3.1-19mdv2010.0
+ Revision: 436071
- Don't use file dependencies anymore

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 3.1-18mdv2010.0
+ Revision: 426008
- rebuild

* Sat Mar 07 2009 Antoine Ginies <aginies@mandriva.com> 3.1-17mdv2009.1
+ Revision: 351537
- rebuild

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 3.1-16mdv2009.0
+ Revision: 223129
- rebuild

* Thu Jan 17 2008 Olivier Blin <oblin@mandriva.com> 3.1-15mdv2008.1
+ Revision: 154077
- remove /etc/networks, it is now in the initscripts package
- restore BuildRoot

* Mon Dec 17 2007 Thierry Vignaud <tv@mandriva.org> 3.1-14mdv2008.1
+ Revision: 129493
- kill re-definition of %%buildroot on Pixel's request


* Fri Mar 09 2007 Stew Benedict <sbenedict@mandriva.com> 3.1-14mdv2007.1
+ Revision: 138766
- oops, need to escape the "$" in creating ulimit scriptlet

* Thu Mar 08 2007 Stew Benedict <sbenedict@mandriva.com> 3.1-13mdv2007.1
+ Revision: 134910
- Work around core size file limit of 0 introduced in setup package
- Drop tjreport in favor of the one packaged in test suites

* Tue Mar 06 2007 Laurent Montel <lmontel@mandriva.com> 3.1-12mdv2007.1
+ Revision: 133697
- Fix requires on x86_64

* Thu Dec 28 2006 Olivier Blin <oblin@mandriva.com> 3.1-11mdv2007.1
+ Revision: 102414
- remove lsb-init-functions from spec
- move lsb-init-functions in initscripts package

* Fri Dec 22 2006 Stew Benedict <sbenedict@mandriva.com> 3.1-10mdv2007.1
+ Revision: 101420
- use %%mklibname for mesagl requires (Anssi Hannula), csh is optional
- add known libX11.so.6 issues to libchk waivers

* Wed Dec 20 2006 Stew Benedict <sbenedict@mandriva.com> 3.1-9mdv2007.1
+ Revision: 100803
- lost libmesagl when xorg was split

* Tue Dec 05 2006 Pixel <pixel@mandriva.com> 3.1-8mdv2007.1
+ Revision: 91265
- /media is now in pkg "filesystem"
- Import lsb

* Fri Jun 02 2006 Stew Benedict <sbenedict@mandriva.com> 3.1-7mdv2007.0
- more requires uncovered in Corp4 beta

* Wed May 24 2006 Stew Benedict <sbenedict@mandriva.com> 3.1-6mdk
- align requires with new X build
- full path to urpmi in common-functions (S0)

* Wed Apr 12 2006 Stew Benedict <sbenedict@mandriva.com> 3.1-5mdk
- -T for core/desktop no longer exists in lsblibchk, lsbcmdchk
- drop warnings about nsswitch.conf

* Sat Apr 01 2006 Stew Benedict <sbenedict@mandriva.com> 3.1-4mdk
- do away with cxx, graphics, desktop packages
- desktop-qt4->qt4
- 3.1 now wants to report just lsb-ver-foo and core-ver-foo
- 3.0 (compat) reports lsb-ver-foo, core-ver-foo, cxx-ver-foo, graphics-ver-foo

* Fri Mar 31 2006 Stew Benedict <sbenedict@mandriva.com> 3.1-3mdk
- core needs to identify as 3.1 also

* Thu Mar 30 2006 Stew Benedict <sbenedict@mandriva.com> 3.1-2mdk
- re-organize again:
  - restore plain lsb, add lsb-cxx
  - lsb requires desktop and below
  - add missing compat_version files for lsb-graphics

* Tue Mar 21 2006 Stew Benedict <sbenedict@mandriva.com> 3.1-1mdk
- 3.1
- add desktop-qt4
- s/2.0/3.0/ compat (we could bring it back with Requires: libstdc++.so.5)
- update libchk and cmdchk autotest scripts to run both core and desktop

* Tue Mar 14 2006 Stew Benedict <sbenedict@mandriva.com> 3.0-12mdk
- use stronger vsx0 passwd in test scripts - was triggering pam failures

* Fri Mar 03 2006 Stew Benedict <sbenedict@mandriva.com> 3.0-11mdk
- add -test and breakout the test specific requires to this subpackage
- move all the "gotcha" notes to README.urpmi in -test

* Thu Mar 02 2006 Stew Benedict <sbenedict@mandriva.com> 3.0-10mdk
- LSB-desktop Requires

* Tue Feb 21 2006 Stew Benedict <sbenedict@mandriva.com> 3.0-9mdk
- split into -core, -graphics, -desktop
- have the test scripts install the appropriate sub-packages
- move some things from lsb-release over to these packages

* Mon Dec 19 2005 Stew Benedict <sbenedict@mandriva.com> 3.0-8mdk
- add lsb-test-xts5 test script
- let common-functions deal with pre-defined $TVERSION

* Fri Nov 11 2005 Stew Benedict <sbenedict@mandriva.com> 3.0-7mdk
- fix/update waivers file

* Thu Aug 04 2005 Stew Benedict <sbenedict@mandriva.com> 3.0-6mdk
- rework automated testing for released LSB-3.0 tests
  - lsb-test-pam no longer used - drop
  - rework lsb-runtime-test
  - rework lsb-test-vsw4
  - add lsb-cmdchk
  - update waivers file
  - rework common-functions
  - rework qmtest_libstdcpp
- some changes to make rpmlint happier

* Sat Jul 02 2005 Stew Benedict <sbenedict@mandriva.com> 3.0-5mdk
- requires s/smtpdaemon/sendmail-command/

* Fri Jun 03 2005 Stew Benedict <sbenedict@mandriva.com> 3.0-4mdk
- requires bc, nail(POSIX compatible mailx, per lsb-cmdchk)
- provide placeholder lsbinstall (still being debated in lsb group)
- requires libstd++.so.6 for LSB3

* Wed May 18 2005 Stew Benedict <sbenedict@mandriva.com> 3.0-3mdk
- re-fix provides on x86_64

* Sat Apr 30 2005 Stew Benedict <sbenedict@mandriva.com> 3.0-2mdk
- try to make LSB2/3 compatible

* Sat Apr 23 2005 Stew Benedict <sbenedict@mandriva.com> 3.0-1mdk
- LSB3.0
- fix install_initd, remove_initd, provides (Mats Wichmann)

* Wed Feb 16 2005 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-15mdk
- adapt test scripts to filter out TSDs from added waiver file
- move common code from test scripts to common-functions (new source0)
- minor patch to tjreport "excluding waived" output (LSB Bugzilla 698)

* Fri Feb 04 2005 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-14mdk
- add test scripts and a README for usage

* Thu Jan 06 2005 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-13mdk
- requires binutils for libstdcpp tests

* Tue Dec 28 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-12mdk
- add tjreport to facilitate automated testing

* Sat Oct 23 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 2.0-11mdk
- rebuild on x86_64

* Sun Oct 10 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-10mdk
- drop libc-extras requires

* Tue Sep 28 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-9mdk
- drop lpddaemon, expect requires

* Tue Sep 21 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-8mdk
- drop nscd requires

* Sun Sep 05 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-7mdk
- remove libxorg-x11-devel requires

* Wed Aug 25 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-6mdk
- add requires for vsw4 tests

* Tue Aug 24 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-5mdk
- locales requires for C++ tests, requires nscd, warning about modprobe loop
i

* Tue Jul 27 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-4mdk
- caveats change with switch from devfs -> udev, drop TMPDIR warning

* Tue Jul 27 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-3mdk
- change provides yet again

* Sat Jul 17 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-2mdk
- change provides to agree with what app-batt expects

* Tue Jun 22 2004 Stew Benedict <sbenedict@mandrakesoft.com> 2.0-1mdk
- LSB2.0 - new requires, provides
- drop groupdel caveat - fixed in test-suite

* Tue Mar 09 2004 Stew Benedict <sbenedict@mandrakesoft.com> 1.3-10mdk
- fix issue with init-functions (Bugzilla #9718)

* Tue Mar 09 2004 Stew Benedict <sbenedict@mandrakesoft.com> 1.3-9mdk
- add /etc/opt, change some dirs to macros
- insure TMPDIR is unset for vsx0

